@@ -38,7 +38,7 @@ class TestLs:
 
         result = runner.invoke(settings, ['ls'])
         assert result.exit_code == 1
-        assert 'You are\'nt logged' in str(result.output)
+        assert 'You aren\'t logged' in str(result.output)
 
     def test_not_found(self, monkeypatch, invalid_data):
         runner = CliRunner()
